@@ -1,4 +1,5 @@
-from Products.PurgeMissingObjectInterfaces import cleaner, check_importable
+from Products.PurgeMissingObjectInterfaces import cleaner
+from FakeZopeInterface.FakeZopeInterface import check_importable
 import pprint, StringIO
 
 def find(self, string='p4a', target='plone'):
@@ -27,6 +28,7 @@ def r_find(self, strings=[]):
     file = StringIO.StringIO()
     pprint.pprint(provides.__dict__, file, depth=100000)
     value = file.getvalue()
+    return value
     found = []
     for string in strings:
         if string in value:
